# streamlit-login-page

Streamlit component that allows you to do X

## Installation instructions 

```sh
pip install streamlit-login-page
```

## Usage instructions

```python
import streamlit as st

from streamlit_login_page import streamlit_login_page

value = streamlit_login_page()

st.write(value)
